==> aws-sdk-cpp-1.11.676-1-x86_64.pkg.tar.zst: usr/include/aws/swf/SWFErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/swf/SWF_EXPORTS.h>

namespace Aws
{
namespace SWF
{
enum class SWFErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  DEFAULT_UNDEFINED_FAULT= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  DOMAIN_ALREADY_EXISTS_FAULT,
  DOMAIN_DEPRECATED_FAULT,
  LIMIT_EXCEEDED_FAULT,
  OPERATION_NOT_PERMITTED_FAULT,
  TOO_MANY_TAGS_FAULT,
  TYPE_ALREADY_EXISTS_FAULT,
  TYPE_DEPRECATED_FAULT,
  TYPE_NOT_DEPRECATED_FAULT,
  UNKNOWN_RESOURCE_FAULT,
  WORKFLOW_EXECUTION_ALREADY_STARTED_FAULT
};

class AWS_SWF_API SWFError : public Aws::Client::AWSError<SWFErrors>
{
public:
  SWFError() {}
  SWFError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}
  SWFError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}
  SWFError(const Aws::Client::AWSError<SWFErrors>& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}
  SWFError(Aws::Client::AWSError<SWFErrors>&& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace SWFErrorMapper
{
  AWS_SWF_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace SWF
} // namespace Aws

==> aws-sdk-cpp-1.11.705-1-x86_64.pkg.tar.zst: usr/include/aws/swf/SWFErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/swf/SWF_EXPORTS.h>

namespace Aws {
namespace SWF {
enum class SWFErrors {
  // From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7,                // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8,  // SDK should never allow
  MISSING_PARAMETER = 9,             // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  DEFAULT_UNDEFINED_FAULT = static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  DOMAIN_ALREADY_EXISTS_FAULT,
  DOMAIN_DEPRECATED_FAULT,
  LIMIT_EXCEEDED_FAULT,
  OPERATION_NOT_PERMITTED_FAULT,
  TOO_MANY_TAGS_FAULT,
  TYPE_ALREADY_EXISTS_FAULT,
  TYPE_DEPRECATED_FAULT,
  TYPE_NOT_DEPRECATED_FAULT,
  UNKNOWN_RESOURCE_FAULT,
  WORKFLOW_EXECUTION_ALREADY_STARTED_FAULT
};

class AWS_SWF_API SWFError : public Aws::Client::AWSError<SWFErrors> {
 public:
  SWFError() {}
  SWFError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}
  SWFError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}
  SWFError(const Aws::Client::AWSError<SWFErrors>& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}
  SWFError(Aws::Client::AWSError<SWFErrors>&& rhs) : Aws::Client::AWSError<SWFErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace SWFErrorMapper {
AWS_SWF_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

}  // namespace SWF
}  // namespace Aws
